@@ -4,15 +4,15 @@ import argparse
 from pathlib import Path
 from typing import Iterable
 
-from pdm.cli.actions import resolve_candidates_from_lockfile
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.filters import GroupSelection
 from pdm.cli.options import groups_group, lockfile_option
 from pdm.exceptions import PdmUsageError
 from pdm.formats import FORMATS
 from pdm.models.candidates import Candidate
-from pdm.models.requirements import Requirement, strip_extras
+from pdm.models.requirements import Requirement
 from pdm.project import Project
+from pdm.project.lockfile import FLAG_INHERIT_METADATA
 
 
 class Command(BaseCommand):
@@ -37,7 +37,11 @@ class Command(BaseCommand):
             help="Don't include artifact hashes",
         )
         parser.add_argument(
-            "--no-markers", action="store_false", default=True, dest="markers", help="Don't include platform markers"
+            "--no-markers",
+            action="store_false",
+            default=True,
+            dest="markers",
+            help="(DEPRECATED)Don't include platform markers",
         )
         parser.add_argument(
             "--no-extras", action="store_false", default=True, dest="extras", help="Strip extras from the requirements"
@@ -63,31 +67,34 @@ class Command(BaseCommand):
         if options.pyproject:
             options.hashes = False
         selection = GroupSelection.from_options(project, options)
-        requirements: dict[str, Requirement] = {}
+        if options.markers is False:
+            project.core.ui.deprecated("The --no-markers option is deprecated and has no effect.")
         packages: Iterable[Requirement] | Iterable[Candidate]
-        for group in selection:
-            requirements.update(project.get_dependencies(group))
         if options.pyproject:
-            packages = requirements.values()
+            packages = [r for group in selection for r in project.get_dependencies(group)]
         else:
             if not project.lockfile.exists():
                 raise PdmUsageError("No lockfile found, please run `pdm lock` first.")
-
-            candidates = resolve_candidates_from_lockfile(
-                project, requirements.values(), groups=set(selection), cross_platform=options.markers
-            )
-
-            filtered_candidates: dict[str, Candidate] = {}
-            for k, candidate in candidates.items():
+            if FLAG_INHERIT_METADATA not in project.lockfile.strategy:
+                raise PdmUsageError(
+                    "Can't export a lock file without environment markers, please re-generate the lock file with `inherit_metadata` strategy."
+                )
+            candidates = [entry.candidate for entry in project.get_locked_repository().packages.values()]
+            groups = set(selection)
+            packages = []
+            seen_extras: set[str] = set()
+            for candidate in candidates:
+                if groups.isdisjoint(candidate.req.groups):
+                    continue
                 if options.extras:
+                    key = candidate.req.key or ""
                     if candidate.req.extras:
-                        k = strip_extras(k)[0]
-                    elif k in filtered_candidates:
+                        seen_extras.add(key)
+                    elif key in seen_extras:
                         continue
                 elif candidate.req.extras:
                     continue
-                filtered_candidates[k] = candidate
-            packages = filtered_candidates.values()
+                packages.append(candidate)  # type: ignore[arg-type]
 
         content = FORMATS[options.format].export(project, packages, options)
         if options.output:
