@@ -227,8 +227,17 @@ class TaskRunner:
         working_dir: str | None = None,
     ) -> int:
         """Run command in a subprocess and return the exit code."""
+        import dotenv
+        from dotenv.main import resolve_variables
+
         project = self.project
-        process_env = os.environ.copy()
+        if not shell and args[0].endswith(".py"):
+            project_env = self._get_script_env(os.path.expanduser(args[0]))
+        else:
+            check_project_file(project)
+            project_env = project.environment
+        this_path = project_env.get_paths()["scripts"]
+        os.environ.update(project_env.process_env)
         if env_file is not None:
             if isinstance(env_file, str):
                 path = env_file
@@ -237,34 +246,21 @@ class TaskRunner:
                 path = env_file["override"]
                 override = True
 
-            import dotenv
-
             project.core.ui.echo(
                 f"Loading .env file: [success]{env_file}[/]",
                 err=True,
                 verbosity=termui.Verbosity.DETAIL,
             )
-            dotenv_env = dotenv.dotenv_values(project.root / path, encoding="utf-8")
-            if override:
-                process_env = {**process_env, **dotenv_env}
-            else:
-                process_env = {**dotenv_env, **process_env}
-        if not shell and args[0].endswith(".py"):
-            project_env = self._get_script_env(os.path.expanduser(args[0]))
-        else:
-            check_project_file(project)
-            project_env = project.environment
-        this_path = project_env.get_paths()["scripts"]
-        process_env.update(project_env.process_env)
+            dotenv.load_dotenv(self.project.root / path, override=override)
         if env:
-            process_env.update(env)
+            os.environ.update(resolve_variables(env.items(), override=True))
         if shell:
             assert isinstance(args, str)
             # environment variables will be expanded by shell
             process_cmd: str | Sequence[str] = args
         else:
             assert isinstance(args, Sequence)
-            command, *args = (expand_env_vars(arg, env=process_env) for arg in args)
+            command, *args = (expand_env_vars(arg) for arg in args)
             if command.endswith(".py"):
                 args = [command, *args]
                 command = str(project_env.interpreter.executable)
@@ -281,7 +277,7 @@ class TaskRunner:
             ):
                 # The executable belongs to the local packages directory.
                 # Don't load system site-packages
-                process_env["NO_SITE_PACKAGES"] = "1"
+                os.environ["NO_SITE_PACKAGES"] = "1"
 
         cwd = (project.root / working_dir) if working_dir else project.root if chdir else None
 
@@ -292,7 +288,7 @@ class TaskRunner:
 
         handle_term = signal.signal(signal.SIGTERM, forward_signal)
         handle_int = signal.signal(signal.SIGINT, forward_signal)
-        process = subprocess.Popen(process_cmd, cwd=cwd, env=process_env, shell=shell, bufsize=0)
+        process = subprocess.Popen(process_cmd, cwd=cwd, shell=shell, bufsize=0)
         process.wait()
         signal.signal(signal.SIGTERM, handle_term)
         signal.signal(signal.SIGINT, handle_int)
