@@ -13,6 +13,7 @@ import tempfile
 from typing import Any, Generator
 
 from pdm.compat import resources_path
+from pdm.models.markers import EnvSpec
 
 
 @contextlib.contextmanager
@@ -21,12 +22,6 @@ def _in_process_script(name: str) -> Generator[str, None, None]:
         yield str(script)
 
 
-@functools.lru_cache
-def get_python_abis(executable: str) -> list[str]:
-    with _in_process_script("get_abis.py") as script:
-        return json.loads(subprocess.check_output(args=[executable, "-EsS", script]))
-
-
 def get_sys_config_paths(executable: str, vars: dict[str, str] | None = None, kind: str = "default") -> dict[str, str]:
     """Return the sys_config.get_paths() result for the python interpreter"""
     env = os.environ.copy()
@@ -39,13 +34,6 @@ def get_sys_config_paths(executable: str, vars: dict[str, str] | None = None, ki
         return json.loads(subprocess.check_output(cmd, env=env))
 
 
-def get_pep508_environment(executable: str) -> dict[str, str]:
-    """Get PEP 508 environment markers dict."""
-    with _in_process_script("pep508.py") as script:
-        args = [executable, "-EsS", script]
-        return json.loads(subprocess.check_output(args))
-
-
 def parse_setup_py(executable: str, path: str) -> dict[str, Any]:
     """Parse setup.py and return the kwargs"""
     with _in_process_script("parse_setup.py") as script:
@@ -57,14 +45,7 @@ def parse_setup_py(executable: str, path: str) -> dict[str, Any]:
 
 
 @functools.lru_cache
-def get_uname(executable: str) -> os.uname_result:
-    """Get uname of the system"""
-    script = "import os, json; print(json.dumps(os.uname()))"
-    return os.uname_result(json.loads(subprocess.check_output([executable, "-EsSc", script])))
-
-
-@functools.lru_cache
-def sysconfig_get_platform(executable: str) -> str:
-    """Get platform from sysconfig"""
-    script = "import sysconfig; print(sysconfig.get_platform())"
-    return subprocess.check_output([executable, "-EsSc", script]).decode().strip()
+def get_env_spec(executable: str) -> EnvSpec:
+    """Get the environment spec of the python interpreter"""
+    with _in_process_script("env_spec.py") as script:
+        return EnvSpec.from_spec(**json.loads(subprocess.check_output([executable, "-Es", script])))
