@@ -15,7 +15,6 @@ import tomlkit
 from pbs_installer import PythonVersion
 from tomlkit.items import Array
 
-from pdm import termui
 from pdm._types import NotSet, NotSetType, RepositoryConfig
 from pdm.compat import CompatibleSequence
 from pdm.exceptions import NoPythonVersion, PdmUsageError, ProjectError
@@ -45,14 +44,13 @@ from pdm.utils import (
 
 if TYPE_CHECKING:
     from findpython import Finder
-    from resolvelib.reporters import BaseReporter
 
-    from pdm._types import Spinner
     from pdm.core import Core
     from pdm.environments import BaseEnvironment
     from pdm.models.caches import CandidateInfoCache, HashCache, WheelCache
     from pdm.models.candidates import Candidate
     from pdm.resolver.providers import BaseProvider
+    from pdm.resolver.reporters import RichLockReporter
 
 
 PYENV_ROOT = os.path.expanduser(os.getenv("PYENV_ROOT", "~/.pyenv"))
@@ -381,25 +379,26 @@ class Project:
 
     @property
     def sources(self) -> list[RepositoryConfig]:
+        return self.get_sources(include_stored=not self.config.get("pypi.ignore_stored_index", False))
+
+    def get_sources(self, expand_env: bool = True, include_stored: bool = False) -> list[RepositoryConfig]:
         result: dict[str, RepositoryConfig] = {}
         for source in self.pyproject.settings.get("source", []):
             result[source["name"]] = RepositoryConfig(**source, config_prefix="pypi")
 
-        add_missing_sources = not self.config.get("pypi.ignore_stored_index", False)
-
         def merge_sources(other_sources: Iterable[RepositoryConfig]) -> None:
             for source in other_sources:
                 name = source.name
                 if name in result:
                     result[name].passive_update(source)
-                elif add_missing_sources:
+                elif include_stored:
                     result[name] = source
 
         merge_sources(self.project_config.iter_sources())
         merge_sources(self.global_config.iter_sources())
         if "pypi" in result:
             result["pypi"].passive_update(self.default_source)
-        elif add_missing_sources:
+        elif include_stored:
             # put pypi source at the beginning
             result = {"pypi": self.default_source, **result}
 
@@ -407,7 +406,8 @@ class Project:
         for source in result.values():
             if not source.url:
                 continue
-            source.url = DEFAULT_BACKEND(self.root).expand_line(expand_env_vars_in_auth(source.url))
+            if expand_env:
+                source.url = DEFAULT_BACKEND(self.root).expand_line(expand_env_vars_in_auth(source.url))
             sources.append(source)
         return sources
 
@@ -498,11 +498,8 @@ class Project:
         return provider_class(repository=repository, direct_minimal_versions=direct_minimal_versions, **params)
 
     def get_reporter(
-        self,
-        requirements: list[Requirement],
-        tracked_names: Iterable[str] | None = None,
-        spinner: Spinner | None = None,
-    ) -> BaseReporter:
+        self, requirements: list[Requirement], tracked_names: Iterable[str] | None = None
+    ) -> RichLockReporter:  # pragma: no cover
         """Return the reporter object to construct a resolver.
 
         :param requirements: requirements to resolve
@@ -510,12 +507,9 @@ class Project:
         :param spinner: optional spinner object
         :returns: a reporter
         """
-        from pdm.resolver.reporters import SpinnerReporter
+        from pdm.resolver.reporters import RichLockReporter
 
-        if spinner is None:
-            spinner = termui.SilentSpinner("")
-
-        return SpinnerReporter(spinner, requirements)
+        return RichLockReporter(requirements, self.core.ui)
 
     def get_lock_metadata(self) -> dict[str, Any]:
         content_hash = "sha256:" + self.pyproject.content_hash("sha256")
@@ -751,7 +745,7 @@ class Project:
                         return
             finder_arg = python_spec
         if search_venv is None:
-            search_venv = config["python.use_venv"]
+            search_venv = cast(bool, config["python.use_venv"])
         finder = self._get_python_finder(search_venv)
         for entry in finder.find_all(finder_arg, allow_prereleases=True):
             yield PythonInfo(entry)
@@ -793,7 +787,7 @@ class Project:
         if "package-type" in settings:
             return settings["package-type"] == "library"
         elif "distribution" in settings:
-            return settings["distribution"]
+            return cast(bool, settings["distribution"])
         else:
             return True
 
@@ -805,7 +799,7 @@ class Project:
         """
         try:
             return reduce(operator.getitem, key.split("."), self.pyproject.settings)
-        except tomlkit.exceptions.NonExistentKey:
+        except KeyError:
             return None
 
     def env_or_setting(self, var: str, key: str) -> Any:
